You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@apr.apache.org by wr...@apache.org on 2008/06/20 19:32:10 UTC

svn commit: r670001 - in /apr/apr/branches/1.3.x: build/buildcheck.sh configure.in

Author: wrowe
Date: Fri Jun 20 10:32:09 2008
New Revision: 670001

URL: http://svn.apache.org/viewvc?rev=670001&view=rev
Log:
Back out the 2.60 requirement, adopt conditional handling for the
new AC_USE_SYSTEM_EXTENSIONS as of 2.60.

Submitted by: Arfrever Frehtes Taifersar Arahesis <arfrever.fta gmail.com>
Backport: r670000

Modified:
    apr/apr/branches/1.3.x/build/buildcheck.sh
    apr/apr/branches/1.3.x/configure.in

Modified: apr/apr/branches/1.3.x/build/buildcheck.sh
URL: http://svn.apache.org/viewvc/apr/apr/branches/1.3.x/build/buildcheck.sh?rev=670001&r1=670000&r2=670001&view=diff
==============================================================================
--- apr/apr/branches/1.3.x/configure.in (original)
+++ apr/apr/branches/1.3.x/configure.in Fri Jun 20 10:32:09 2008
@@ -139,9 +139,14 @@
 AC_CHECK_TOOL(AR, ar, ar)
 
 dnl Various OS checks that apparently set required flags
+ifdef([AC_USE_SYSTEM_EXTENSIONS], [
 AC_USE_SYSTEM_EXTENSIONS
-AC_ISC_POSIX
+], [
+AC_AIX
+AC_MINIX
+])
 
+AC_ISC_POSIX
 APR_EBCDIC
 
 dnl this is our library name
--- apr/apr/branches/1.3.x/build/buildcheck.sh (original)
+++ apr/apr/branches/1.3.x/build/buildcheck.sh Fri Jun 20 10:32:09 2008
@@ -14,18 +14,18 @@
 echo "buildconf: python version $py_version (ok)"
 fi
 
 # autoconf 2.60 or newer
 ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|sed -e 's/^[^0-9]*//;s/[a-z]* *$//;q'`
 if test -z "$ac_version"; then
 echo "buildconf: autoconf not found."
-echo "           You need autoconf version 2.60 or newer installed"
+echo "           You need autoconf version 2.50 or newer installed"
 echo "           to build APR from SVN."
 exit 1
 fi
 IFS=.; set $ac_version; IFS=' '
-if test "$1" = "2" -a "$2" -lt "60" || test "$1" -lt "2"; then
+if test "$1" = "2" -a "$2" -lt "50" || test "$1" -lt "2"; then
 echo "buildconf: autoconf version $ac_version found."
-echo "           You need autoconf version 2.60 or newer installed"
+echo "           You need autoconf version 2.50 or newer installed"
 echo "           to build APR from SVN."
 exit 1
 else
@@ -14,18 +14,18 @@
 fi
 
-# autoconf 2.60 or newer
+# autoconf 2.50 or newer
 ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|sed -e 's/^[^0-9]*//;s/[a-z]* *$//;q'`
 if test -z "$ac_version"; then

Modified: apr/apr/branches/1.3.x/configure.in
URL: http://svn.apache.org/viewvc/apr/apr/branches/1.3.x/configure.in?rev=670001&r1=670000&r2=670001&view=diff
==============================================================================